@@ -19,11 +19,9 @@ class Initializer:
     def session(self) -> Union[AsyncSession, async_scoped_session]:
         return self._session
 
-    def init(self, db_url: str, engine_args: dict, session_args: dict) -> None:
+    def init(self, db_url: str, engine_args, session_args) -> None:
         engine = create_async_engine(db_url, **engine_args)
-        async_session_factory = sessionmaker(
-            bind=engine, class_=AsyncSession, **session_args
-        )
+        async_session_factory = sessionmaker(bind=engine, **session_args)
         self._session: Union[AsyncSession, async_scoped_session] = async_scoped_session(
             session_factory=async_session_factory,
             scopefunc=get_session_context,
